<?php

/**
 * @file
 */

namespace Drupal\content_snapshot\Encoder;

use Symfony\Component\Serializer\Encoder\DecoderInterface;
use Symfony\Component\Serializer\Encoder\EncoderInterface;
use Symfony\Component\Yaml\Dumper;
use Symfony\Component\Yaml\Parser;

/**
 * We are using custom yaml encoder and format as long as Drupal doesn't have
 * one in core, after that happen, this class and format will become deprecated.
 */
class YamlEncoder implements EncoderInterface, DecoderInterface {

  /**
   * The formats that this Encoder supports.
   *
   * @var string
   */
  public const FORMAT = 'yaml_content_snapshot';

  /**
   * @var Dumper
   */
  private $dumper;

  /**
   * @var Parser
   */
  private $parser;

  public function __construct() {
    $this->dumper = new Dumper(2);
    $this->parser = new Parser();
  }


  public function encode(mixed $data, string $format, array $context = []): string {
    return $this->dumper->dump($data, PHP_INT_MAX);
  }

  public function supportsEncoding(string $format): bool {
    return $format === static::FORMAT;
  }

  public function decode(string $data, string $format, array $context = []): mixed {
    return $this->parser->parse($data);
  }

  public function supportsDecoding(string $format): bool {
    return $format === static::FORMAT;
  }

}
